EnsureGlobsExpandedAction
=========================

.. currentmodule:: wwt_data_formats.cli

.. autoclass:: EnsureGlobsExpandedAction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~EnsureGlobsExpandedAction.__call__
      ~EnsureGlobsExpandedAction.expand_globs

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expand_globs
